/*********************************************************************
 *
 *                Microchip USB C18 Firmware Version 1.0
 *
 *********************************************************************
 * FileName:        main.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the CompanyE for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS ISECONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 ********************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"
#include "system\usb\usb.h"

#include "system\usb\usb_compile_time_validation.h" // Optional
#include "user\user.h"                        // Modifiable

/** D E F I N I T I O N S ****************************************************/
   

/** V A R I A B L E S ********************************************************/
#pragma udata

/** P R I V A T E  P R O T O T Y P E S ***************************************/
static void InitializeSystem(void);

void usb_itr (void);
/** V E C T O R  R E M A P P I N G *******************************************/
// ȉ̐sRgAEgŔhύX_.txthĂB


#pragma code high_vector = 0x08
void high_interrupt (void)
{
    _asm goto usb_itr _endasm
}

/** D E C L A R A T I O N S **************************************************/
#pragma code
/******************************************************************************
 * Function:        void main(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Main program entry point.
 *
 * Note:            None
 *****************************************************************************/

void main(void)
{
    InitializeSystem();

	while((usb_device_state < CONFIGURED_STATE)||(UCONbits.SUSPND==1)) INTCONbits.GIE=1;

	while(1){
		#if defined(USB_USE_CDC)
		CDCTxService();	//I wonder whether the position of this function is correct or not.
		#endif
		INTCONbits.GIE=1;
	}
}//end main


/******************************************************************************
 * Function:        static void InitializeSystem(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        InitializeSystem is a centralize initialization routine.
 *                  All required USB initialization routines are called from
 *                  here.
 *
 *                  User application initialization routine should also be
 *                  called from here.                  
 *
 * Note:            None
 *****************************************************************************/
static void InitializeSystem(void)
{
    ADCON1 |= 0x0F;                 // Default all pins to digital
    
    mInitializeUSBDriver();         // See usbdrv.h
	UserInit();                     // See user.c & .h
	USBCheckBusStatus();			// yts: poling method is needed for self_ and/or bus_ power senses.

}//end InitializeSystem


void usb_itr (void)
{
	USBDriverService();
}

//configulationǉ܂***********************************************
#pragma config PLLDIV = 5 
#pragma config CPUDIV = OSC1_PLL2 
#pragma config USBDIV = 2 

#pragma config FOSC = HS 
#pragma config FCMEM = OFF 
#pragma config IESO = OFF 

#pragma config PWRT = OFF 
#pragma config BOR = ON 
#pragma config BORV = 28 
#pragma config VREGEN = ON 

#pragma config WDT = OFF 
#pragma config WDTPS = 1 

#pragma config MCLRE = ON 
#pragma config LPT1OSC = OFF 
#pragma config PBADEN = OFF 
#pragma config CCP2MX = OFF

#pragma config STVREN = OFF 
#pragma config LVP = OFF 
#pragma config ICPRT = OFF 
#pragma config XINST = OFF 
#pragma config DEBUG = OFF 

#pragma config CP0 = OFF 
#pragma config CPB = OFF 
#pragma config WRT0 = OFF 
#pragma config WRTB = OFF 
#pragma config EBTR0 = OFF 
#pragma config EBTRB = OFF
/** EOF main.c ***************************************************************/
